
# Type: c3




URI: [ex:C3](http://example.org/mappings/C3)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/[C1]^-[C3&#124;s1(i):string%20%3F;s2(i):identifier_type])

## Parents

 *  is_a: [C1](C1.md)

## Attributes


### Inherited from c1:

 * [s1](s1.md)  <sub>OPT</sub>
    * range: [String](types/String.md)
    * inherited from: [C1](C1.md)
 * [s2](s2.md)  <sub>REQ</sub>
    * range: [IdentifierType](types/IdentifierType.md)
    * inherited from: [C1](C1.md)
